# History

## 0.3.2 (2025-10-03)

- Put upper limit for setuptools, because pkg_resources will not be in version 81

## 0.3.1 (2025-05-15)

- Add deprecated SPDX licenses
- Add missing spellings of SPDX licenses
- Merge "GNU lesser general public license v2 (lgplv2)" into "GNU Lesser General Public License v2.0 only"
- Merge "GNU lesser general public license v3 (lgplv3)" into "GNU Lesser General Public License v3.0 only"
- Merge "Affero General Public License v1.0 only" into "GNU Affero General Public License v1.0 only"
- Merge "Affero General Public License v1.0 or later" into "GNU Affero General Public License v1.0 or later"
- Merge "GNU Affero general public license v3 (aplv3)" into "GNU Affero General Public License v3.0 only"

## 0.3.0 (2025-05-12)

- Added all SPDX licenses

## 0.2.12 (2025-04-03)

- Added "Python software foundation license v1" and "Python software foundation license v2" as synonyms

## 0.2.11 (2025-04-03)

- Adding Python Software Foundation V1 and V2, plus a lot of synonyms for it

## 0.2.10 (2025-03-19)

- Change "apache-2.0 or bsd" to map apache_license_v2, instead of BSD 2-clause license. Because bsd can refer to 4-clause too but apache-2.0 is more likely to be one you want to use

## 0.2.9 (2025-03-12)

- Improve the error message for UNKOWN license

## 0.2.8 (2025-02-28)

- Check for metadata for License-Expression in line with [PEP 639](https://peps.python.org/pep-0639/)

## 02.7 (2024-10-23)

- Add MIT-CMU (the new license of Pillow)
- Make print mode work WITHOUT pyproject.toml in folder

## 0.2.6 (2024-06-24)

- Remove sparkels emoticons and replace with =+=+=+ for issue 14

## 0.2.5 (2023-08-15)

- Add zope
- Add unlicensed
- Add Azure license
- Add CC0
- Add MIT-0

## 0.2.4 (2023-08-09)

- Print finish message

## 0.2.3 (2023-08-09)

- Give arguments priority over classifier
  
## 0.2.2 (2023-08-09)

- Bugfix: fix cli
  
## 0.2.1 (2023-08-09)

- Bugfix: Make it work with python < 3.11

## 0.2.0 (2023-08-05)

- Add whitelisted mode to CLI

## 0.1.3 (2023-07-26)

- Fix mislabeling of 2 AGPL v3 as GPL v3

## 0.0.1 (2023-01-10)

- Add license scanner
- Find all licenses in your env

## 0.0.0 (1970-01-01)

- Copied basic package a start of license_scanner
